# Prevent brp-java-repack-jars from being run.
%global __jar_repack %{nil}

%global checkForbiddenJARFiles F=`find -type f -iname '*.jar'`; [ ! -z "$F" ] && \
echo "ERROR: Sources should not contain JAR files:" && echo "$F" && exit 1

%global fm_compatible_ver 2.3
%global fm_ver %{fm_compatible_ver}.23

Name:           freemarker
Version:        %{fm_ver}
Release:        %mkrel 3
Group:          Development/Java
Summary:        A template engine
License:        BSD
URL:            http://freemarker.sourceforge.net/
Source0:        http://downloads.sourceforge.net/%{name}/%{name}-%{version}.tar.gz

# Remove JSP 1.x and 2.0 API usage
Patch1:         jsp-api.patch
# Compile only the classes compatible with the version of jython
Patch2:         jython-compatibility.patch
# illegal character in the javadoc comment
Patch3:         fix-javadoc-encoding.patch
# Fix ivy configuration
Patch4:         ivy-configuration.patch
# Disable JavaRebelIntegration
Patch5:         no-javarebel.patch
# enable jdom extension
Patch6:         enable-jdom.patch
# use system javacc and fix Token.java
Patch7:         javacc.patch

BuildArch:      noarch

BuildRequires: ant >= 1.6
BuildRequires: apache-parent
BuildRequires: apache-commons-logging
BuildRequires: apache-commons-io
BuildRequires: aqute-bnd
BuildRequires: avalon-logkit >= 1.2
BuildRequires: dom4j >= 1.6.1
BuildRequires: emma >= 2.0
BuildRequires: findbugs
BuildRequires: hamcrest
BuildRequires: ivy-local
BuildRequires: java-devel >= 1:1.6.0
BuildRequires: javacc >= 4.0
BuildRequires: javapackages-local
BuildRequires: jaxen >= 1.1
BuildRequires: jboss-jsp-2.2-api
BuildRequires: jcl-over-slf4j
BuildRequires: jdom >= 1.0
BuildRequires: jetty-jsp
BuildRequires: jetty-webapp
BuildRequires: junit >= 3.8.2
BuildRequires: jython >= 2.2.1
BuildRequires: log4j >= 1.2
BuildRequires: log4j-over-slf4j
BuildRequires: logback
BuildRequires: rhino >= 1.6
BuildRequires: sonatype-oss-parent
BuildRequires: saxpath
BuildRequires: slf4j
BuildRequires: xalan-j2 >= 2.7.0

%description
FreeMarker is a Java tool to generate text output based on templates.
It is designed to be practical as a template engine to generate web
pages and particularly for servlet-based page production that follows
the MVC (Model View Controller) pattern. That is, you can separate the
work of Java programmers and website designers - Java programmers
needn't know how to design nice websites, and website designers needn't
know Java programming.

%package javadoc
Summary:        Javadoc for %{name}

%description javadoc
This package contains the API documentation for %{name}.

%prep
%setup -q -n %{name}-%{version} -c


find . -name "*.jar" -delete
find . -name "*.class" -delete
rm -rf documentation/_html/api/

%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch6 -p1
%patch7 -p1

%{__rm} -rf source/ivysettings.xml

# %%{__rm} -rf src/freemarker/core/ParseException.java
%{__rm} -rf source/src/freemarker/core/FMParser.java
%{__rm} -rf source/src/freemarker/core/FMParserConstants.java
%{__rm} -rf source/src/freemarker/core/FMParserTokenManager.java
%{__rm} -rf source/src/freemarker/core/SimpleCharStream.java
%{__rm} -rf source/src/freemarker/core/Token.java
%{__rm} -rf source/src/freemarker/core/TokenMgrError.java

%checkForbiddenJARFiles

%mvn_file org.%{name}:%{name} %{name}

%build
cd source
ant -Divy.mode=local javacc jar javadoc maven-pom

%install
%mvn_artifact source/build/pom.xml source/build/%{name}.jar
%mvn_install -J source/build/api

%files -f .mfiles
%doc README.txt
%license LICENSE.txt NOTICE.txt

%files javadoc -f .mfiles-javadoc
%license LICENSE.txt NOTICE.txt




%changelog
* Wed Mar 02 2016 neoclust <neoclust> 2.3.23-3.mga6
+ Revision: 981896
- Second rebuild of the java stack

* Sun Feb 28 2016 neoclust <neoclust> 2.3.23-2.mga6
+ Revision: 980489
- New version
- First rebuild of the java stack

* Tue Feb 09 2016 umeabot <umeabot> 2.3.19-10.mga6
+ Revision: 951918
- Mageia 6 Mass Rebuild

* Sun Jan 11 2015 pterjan <pterjan> 2.3.19-9.mga5
+ Revision: 809888
- Sync with Fedora 21

* Wed Oct 15 2014 umeabot <umeabot> 2.3.19-8.mga5
+ Revision: 740292
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 2.3.19-7.mga5
+ Revision: 679342
- Mageia 5 Mass Rebuild

* Mon Jan 06 2014 dmorgan <dmorgan> 2.3.19-6.mga4
+ Revision: 565148
- Fix source for pom file

* Thu Jan 02 2014 dmorgan <dmorgan> 2.3.19-5.mga4
+ Revision: 564000
- Adapt to tomcat 7

* Sat Oct 19 2013 umeabot <umeabot> 2.3.19-4.mga4
+ Revision: 530958
- Mageia 4 Mass Rebuild

* Tue Jul 30 2013 joequant <joequant> 2.3.19-3.mga4
+ Revision: 461159
- remove java-nodeps from buildrequires

* Fri Jan 11 2013 umeabot <umeabot> 2.3.19-2.mga3
+ Revision: 350917
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Sep 10 2012 dmorgan <dmorgan> 2.3.19-1.mga3
+ Revision: 291749
- New version

* Wed Oct 19 2011 gil <gil> 2.3.16-1.mga2
+ Revision: 156652
- update to 2.3.16
- edit depmap for backward compatibility
- added maven2 pom

* Thu Apr 28 2011 dmorgan <dmorgan> 2.3.13-13.mga1
+ Revision: 92443
- Rebuild after bootstrapping
- imported package freemarker


* Wed Mar 16 2011 Omair Majid <omajid@redhat.com> - 2.3.13-12
- Drop build dependency on struts
- Remove buildroot cleaning and definition
- Remove versioned jars
- Remove dependency of javadoc subpackage on main package

* Mon Feb 28 2011 Omair Majid <omajid@redhat.com> - 2.3.13-12
- Remove dependency on tomcat5

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.3.13-11
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Mon Sep 13 2010 Alexander Kurtakov <akurtako@redhat.com> 2.3.13-10
- Adapt to tomcat6-el jar rename.

* Mon Sep 13 2010 Alexander Kurtakov <akurtako@redhat.com> 2.3.13-9
- Add tomcat6-libs BR.
- Use global instead of define.

* Sat Feb 27 2010 Victor G. Vasilyev <victor.vasilyev@sun.com> 2.3.13-8
- fix build patch for use of the javacc 5.0
- patch for encoding
- disable brp-java-repack-jars

* Sat Feb 27 2010 Victor G. Vasilyev <victor.vasilyev@sun.com> 2.3.13-7
- patch for logging
- remove name from the summary

* Fri Jul 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.3.13-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Tue Feb 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.3.13-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Mon Sep 01 2008 Victor G. Vasilyev <victor.vasilyev@sun.com> 2.3.13-4
- Redundant dependency upon xerces-j2 is removed (#456276#c6)
- The dos2unix package is added as the build requirements
- The ant-nodeps build-time requirement is added

* Wed Aug 20 2008 Victor G. Vasilyev <victor.vasilyev@sun.com> 2.3.13-3
- The downloads.sourceforge.net host is used in the source URL
- %%{__install} and %%{__cp} are used everywhere
- %%defattr(-,root,root,-) is used everywhere

* Fri Aug 14 2008 Victor G. Vasilyev <victor.vasilyev@sun.com> 2.3.13-2
- Appropriate values of Group Tags are chosen from the official list
- Versions of java-devel & jpackage-utils are corrected
- Name of dir for javadoc is changed
- Manual is removed due to http://freemarker.org/docs/index.html

* Fri Jun 06 2008 Victor G. Vasilyev <victor.vasilyev@sun.com> 2.3.13-1
- Initial version
